# LeetPie

```
pip install leetpie
```

**Usage**:

```console
$ leetpie [OPTIONS] COMMAND [ARGS]...
```

**Commands**:

- `check`
- `review`
- `test`

## `leetpie check`

**Usage**:

```console
$ leetpie check [OPTIONS]
```

**Options**:

- `--help`: Show this message and exit.

## `leetpie review`

**Usage**:

```console
$ leetpie review [OPTIONS] [TAG]
```

**Arguments**:

- `[TAG]`

**Options**:

- `-s, --solution`: show solution
- `-m, --markdown`: generate markdown
- `--help`: Show this message and exit.

## `leetpie test`

**Usage**:

```console
$ leetpie test [OPTIONS] PROBLEM_ID
```

**Arguments**:

- `PROBLEM_ID`: [required]

**Options**:

- `--help`: Show this message and exit.
